summaryrefslogtreecommitdiffstats
path: root/sys/ia64
diff options
context:
space:
mode:
authorjhb <jhb@FreeBSD.org>2001-02-22 16:56:53 +0000
committerjhb <jhb@FreeBSD.org>2001-02-22 16:56:53 +0000
commit5eea0dc69dfd1dcc9440839fc5c499a5e90e3cec (patch)
tree7cbbba9eec4bf616b87ca9fad2f7d5cda5d79d24 /sys/ia64
parentd523baf7a30c4175ade6f6fb150ebbbbdb7643f3 (diff)
downloadFreeBSD-src-5eea0dc69dfd1dcc9440839fc5c499a5e90e3cec.zip
FreeBSD-src-5eea0dc69dfd1dcc9440839fc5c499a5e90e3cec.tar.gz
Rename switch_trampoline() to fork_trampoline() on the alpha and ia64.
Suggested by: dfr
Diffstat (limited to 'sys/ia64')
-rw-r--r--sys/ia64/ia64/swtch.s6
-rw-r--r--sys/ia64/ia64/vm_machdep.c4
-rw-r--r--sys/ia64/include/cpu.h2
3 files changed, 6 insertions, 6 deletions
diff --git a/sys/ia64/ia64/swtch.s b/sys/ia64/ia64/swtch.s
index a08bc25..10f568e 100644
--- a/sys/ia64/ia64/swtch.s
+++ b/sys/ia64/ia64/swtch.s
@@ -612,7 +612,7 @@ ENTRY(restorehighfp, 1)
END(restorehighfp)
/*
- * switch_trampoline()
+ * fork_trampoline()
*
* Arrange for a function to be invoked neatly, after a cpu_switch().
*
@@ -623,7 +623,7 @@ END(restorehighfp)
* The callout function is in r4, the address to return to after executing
* fork_exit() is in r5, and the argument is in r6.
*/
-ENTRY(switch_trampoline, 0)
+ENTRY(fork_trampoline, 0)
alloc r14=ar.pfs,0,0,3,0
;;
mov b0=r5
@@ -633,5 +633,5 @@ ENTRY(switch_trampoline, 0)
;;
br.call.sptk.few b6=fork_exit
- END(switch_trampoline)
+ END(fork_trampoline)
diff --git a/sys/ia64/include/cpu.h b/sys/ia64/include/cpu.h
index 98629b6..5a5257a 100644
--- a/sys/ia64/include/cpu.h
+++ b/sys/ia64/include/cpu.h
@@ -151,7 +151,7 @@ int savectx __P((struct pcb *));
void restorectx __P((struct pcb *));
void set_iointr __P((void (*)(void *, unsigned long)));
void switch_exit __P((struct proc *)); /* MAGIC */
-void switch_trampoline __P((void)); /* MAGIC */
+void fork_trampoline __P((void)); /* MAGIC */
void syscall __P((int, u_int64_t *, struct trapframe *));
void trap __P((int vector, int imm, struct trapframe *framep));
OpenPOWER on IntegriCloud
diff --git a/sys/ia64/ia64/vm_machdep.c b/sys/ia64/ia64/vm_machdep.c
index 4a280d6..09ce462 100644
--- a/sys/ia64/ia64/vm_machdep.c
+++ b/sys/ia64/ia64/vm_machdep.c
@@ -256,7 +256,7 @@ cpu_fork(p1, p2, flags)
* child process doesn't stay in the kernel for long!
*
* We should really deal with the function descriptor
* for fork_return() in switch_trampoline() so that a
* kthread started from a loaded module can have the
* right value for gp.
*/
@@ -264,7 +264,7 @@ cpu_fork(p1, p2, flags)
up->u_pcb.pcb_r4 = FDESC_FUNC(fork_return);
up->u_pcb.pcb_r5 = FDESC_FUNC(exception_restore);
up->u_pcb.pcb_r6 = (u_int64_t)p2;
- up->u_pcb.pcb_b0 = FDESC_FUNC(switch_trampoline);
+ up->u_pcb.pcb_b0 = FDESC_FUNC(fork_trampoline);
}
}
@@ -256,7 +256,7 @@ cpu_fork(p1, p2, flags)
*
* We should really deal with the function descriptor
- * for fork_return() in switch_trampoline() so that a
+ * for fork_return() in fork_trampoline() so that a
* kthread started from a loaded module can have the
* right value for gp.